@@ -2,7 +2,7 @@ package HTML::SocialMeta::Base;
 use Moo;
 use Carp;
 
-our $VERSION = '0.74002';
+our $VERSION = '0.74003';
 
 use MooX::LazierAttributes qw/rw ro lzy dhash lzy_str coe/;
 use MooX::ValidateSubs;
@@ -76,7 +76,7 @@ sub _generate_meta_tag {
 
 sub _build_field {
     return sprintf q{<meta %s="%s:%s" content="%s"/>}, $_[0]->meta_attribute,
-      ( $_[1]->{ignore_meta_namespace} // $_[0]->meta_namespace ),
+      ( $_[1]->{ignore_meta_namespace} || $_[0]->meta_namespace ),
       ( defined $_[1]->{field_type} ? $_[1]->{field_type} : $_[1]->{field} ),
       $_[0]->{$_[1]->{field}};
 }
@@ -114,7 +114,7 @@ builds and returns the Meta Tags
 
 =head1 VERSION
 
-Version 0.74002
+Version 0.74003
 
 =cut
 
